@@ -5,7 +5,6 @@ Created on 2015-8-8
 @author: cheng.li
 """
 
-from PyFin.Math.Accumulators.IAccumulators import TruncatedValueHolder
 from PyFin.Math.Accumulators.IAccumulators import Exp
 from PyFin.Math.Accumulators.IAccumulators import Log
 from PyFin.Math.Accumulators.IAccumulators import Sqrt
@@ -35,15 +34,7 @@ from PyFin.Math.Accumulators.StatelessAccumulators import Sum
 from PyFin.Math.Accumulators.StatelessAccumulators import Average
 from PyFin.Math.Accumulators.StatelessAccumulators import XAverage
 from PyFin.Math.Accumulators.StatelessAccumulators import Variance
-from PyFin.Math.Accumulators.StatelessAccumulators import Correlation
 from PyFin.Math.Accumulators.StatelessAccumulators import Product
-from PyFin.Math.Accumulators.StatelessAccumulators import CenterMoment
-from PyFin.Math.Accumulators.StatelessAccumulators import Skewness
-from PyFin.Math.Accumulators.StatelessAccumulators import Kurtosis
-from PyFin.Math.Accumulators.StatelessAccumulators import Rank
-from PyFin.Math.Accumulators.StatelessAccumulators import LevelList
-from PyFin.Math.Accumulators.StatelessAccumulators import LevelValue
-from PyFin.Math.Accumulators.StatelessAccumulators import AutoCorrelation
 
 from PyFin.Math.Accumulators.StatefulAccumulators import Shift
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverage
@@ -59,35 +50,22 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingStandardDeviation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelationMatrix
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMin
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingRank
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingQuantile
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAllTrue
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAnyTrue
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingHistoricalWindow
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingProduct
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingCenterMoment
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingSkewness
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingMaxPos
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingMinPos
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingKurtosis
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingRSV
 from PyFin.Math.Accumulators.StatefulAccumulators import MACD
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingRank
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingKDJ
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingLevel
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingAroon
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingBias
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingAutoCorrelation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingLogReturn
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingResidue
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingAlphaBeta
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingDrawDown
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverageDrawdown
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingMaxDrawdown
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingSharp
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingSortino
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingDrawdown
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingMaxDrawdown
+
 
 __all__ = ["Exp",
            "Log",
@@ -112,12 +90,10 @@ __all__ = ["Exp",
            "Min",
            "Minimum",
            "Sum",
-           "TruncatedValueHolder",
            "Average",
            "XAverage",
            "MACD",
            "Variance",
-           "Correlation",
            "Shift",
            "IIF",
            "Identity",
@@ -131,11 +107,10 @@ __all__ = ["Exp",
            "MovingCountedPositive",
            "MovingCountedNegative",
            "MovingNegativeVariance",
-           "MovingHistoricalWindow",
            "MovingCorrelation",
-           "MovingCorrelationMatrix",
            "MovingMax",
            "MovingMin",
+           "MovingRank",
            "MovingQuantile",
            "MovingAllTrue",
            "MovingAnyTrue",
@@ -143,30 +118,9 @@ __all__ = ["Exp",
            "MovingStandardDeviation",
            "MovingLogReturn",
            "MovingResidue",
-           "MovingAlphaBeta",
-           "MovingDrawDown",
-           "MovingAverageDrawdown",
-           "MovingMaxDrawdown",
            "MovingSharp",
            "MovingSortino",
+           "MovingDrawdown",
+           "MovingMaxDrawdown",
            "Product",
-           "CenterMoment",
-           "Skewness",
-           "MovingProduct",
-           "MovingCenterMoment",
-           "MovingSkewness",
-           "MovingMaxPos",
-           "MovingMinPos",
-           "Kurtosis",
-           "MovingKurtosis",
-           "MovingRSV",
-           "MovingRank",
-           "Rank",
-           "MovingKDJ",
-           "MovingAroon",
-           "MovingBias",
-           "MovingLevel",
-           "LevelValue",
-           "LevelList",
-           "AutoCorrelation",
-           "MovingAutoCorrelation"]
+           "MovingProduct"]
